"""
Module qui permet de générer et afficher une trajectoire Brownienne.

Les calculs sont effectués via l'équation de Langevin, en considérant une force
aléatoire de type gaussienne.

Le temps est discrétisé, et la position de la particule est en une seule dimension x.
"""

### Import des modules
import numpy as np
import matplotlib.pyplot as plt
plt.ion() # Mode interactif activé
plt.style.use('bmh')

### Définition des fonctions
# Fonctions principales de l'algorithme
def move_particle(xi,v,dt):
  """
    Met à jour la position de la particule selon une trajectoire brownienne.

    Parameters
    ----------
    xi : float, optional
        Position de la particule au temps ti
    v : float
        vitesse de la particule
    dt : float
        Pas de temps élémentaire

    Returns
    -------
    xip1 : float
        Position de la particule brownienne au temps i+1
    """
    ..........................  (à compléter)

    return xip1

  

# Affichages
def plot_curve(x, y, xlabel="", ylabel="", legend="", title="",
                xlog=False, ylog=False, fignumber=0, clear=False):

    # Créé ou récupère la figure
    plt.figure(fignumber, figsize=(7, 5))
    # Efface la figure courante si besoin
    if clear: plt.clf()
    # Affiche la courbe et la légende
    if legend:
        plt.plot(x,y,'.-',label=legend)
        plt.legend()
    else:
        plt.plot(x,y,'.-') # Ligne + points
    # Affiche le titre si besoin
    if title: plt.title(title)
    # Passe les échelles en log si besoin
    if xlog: plt.xscale("log")
    if ylog: plt.yscale("log")
    # Affiche les labels
    plt.xlabel(xlabel)
    plt.ylabel(ylabel)
    # Affiche le graphique
    #plt.show()

def plot_histogram(x, nbins, xlabel="", ylabel="", legend="", title="",
                xlog=False, ylog=False, fignumber=0, clear=False):

    # Créé ou récupère la figure
    plt.figure(fignumber, figsize=(7, 5))
    # Efface la figure courante si besoin
    if clear: plt.clf()
    # Affiche la courbe et la légende
    if legend:
        plt.hist(x,bins=nbins,histtype='step',lw=2,label=legend)
        plt.legend()
    else:
        plt.hist(x,bins=nbins,histtype='step',lw=2)
    # Affiche le titre si besoin
    if title: plt.title(title)
    # Passe les échelles en log si besoin
    if xlog: plt.xscale("log")
    if ylog: plt.yscale("log")
    # Affiche les labels
    plt.xlabel(xlabel)
    plt.ylabel(ylabel)
    # Affiche le graphique
  #  plt.show()

# Calculs
def calculate_mean_squared_displacement(xk):
    """
    Calcule le déplacement quadratique moyen des particules à l'instant ti.

    Parameters
    ----------
    list_xi : list of array
        Liste des positions de toutes les particules à l'instant ti

    Returns
    -------
    sigma2 : float
        Déplacement quadratique moyen des particules
    """
    # On récupère le nombre total de trajectoires
    #N = len(xk)
    # On initialise le déplacement quadratique moyen
    # FONCTION A COMPLETER
    